==> krusader_1.51.orig.tar.gz: krusader-1.51/krusader/UserMenu/usermenu.h <==
/***************************************************************************
                     usermenu.h  -  description
                        -------------------
begin                : Sat Dec 6 2003
copyright            : (C) 2003 by Shie Erlich & Rafi Yanai
email                :
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef USERMENU_H
#define USERMENU_H

#include <kpopupmenu.h>

class UserActionProperties;
class QWidget;
class UserMenuAdd;
class UserMenu;

class UserMenuGui: public KPopupMenu {
      Q_OBJECT
   public:
      UserMenuGui( UserMenu* menu, QWidget *parent = 0 );
      void run();

   protected:
      void readEntries();

   protected slots:
      void addEntry( UserActionProperties *properties );
   public slots:
      void createMenu();

   private:
      UserMenuAdd *_addgui;
};

class UserMenu : public QWidget {
   public:
      UserMenu( QWidget *parent = 0, const char *name = 0 );
      void exec();
      void update();
   
   private:
      UserMenuGui* _popup;
};

#endif

==> krusader_2.0.0.orig.tar.gz: krusader-2.0.0/krusader/UserMenu/usermenu.h <==
/***************************************************************************
                     usermenu.h  -  description
                        -------------------
begin                : Sat Dec 6 2003
copyright            : (C) 2003 by Shie Erlich & Rafi Yanai
email                :
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef USERMENU_H
#define USERMENU_H

#include <kmenu.h>

class QWidget;
class UserMenu;
class QAction;

class UserMenuGui: public KMenu {
   public:
      UserMenuGui( UserMenu* menu, QWidget *parent = 0 );
      void run();
      void createMenu();

   protected:
      void readEntries();

   private:
      QAction* _manageAction;
};

class UserMenu : public QWidget {
   public:
      UserMenu( QWidget *parent = 0 );
      void exec();
      void update();
   
   private:
      UserMenuGui* _popup;
};

#endif
